@@ -27,6 +27,8 @@ class Getters(LibraryComponent):
         """Returns the current URL.
 
         Optionally asserts that it matches the specified assertion.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetUrl(Request().Empty())
@@ -44,6 +46,8 @@ class Getters(LibraryComponent):
     ) -> object:
         """Returns page model state object.
 
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+
         This must be given on the page to ``window.__SET_RFBROWSER_STATE__``
 
         For example:
@@ -60,6 +64,26 @@ class Getters(LibraryComponent):
                 value, assertion_operator, assertion_expected, "State "
             )
 
+    @keyword(tags=["Getter", "BrowserControl"])
+    def get_page_source(
+        self,
+        assertion_operator: Optional[AssertionOperator] = None,
+        assertion_expected: Any = None,
+    ) -> str:
+        """Gets pages HTML source as a string.
+
+        Optionally does a string assertion.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+        """
+        with self.playwright.grpc_channel() as stub:
+            response = stub.GetPageSource(Request().Empty())
+            logger.debug(response.log)
+            value = json.loads(response.body)
+            return verify_assertion(
+                value, assertion_operator, assertion_expected, "HTML: "
+            )
+
     @keyword(tags=["Getter", "Assertion", "PageContent"])
     def get_title(
         self,
@@ -69,6 +93,8 @@ class Getters(LibraryComponent):
         """Returns the title of the current page.
 
         Optionally asserts that it matches the specified assertion.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetTitle(Request().Empty())
@@ -88,6 +114,8 @@ class Getters(LibraryComponent):
         """Returns text attribute of the element found by ``selector``.
 
         Optionally asserts that the text matches the specified assertion.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetDomProperty(
@@ -107,10 +135,16 @@ class Getters(LibraryComponent):
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
     ):
-        """Returns ``attribute`` of the element found by ``selector``.
+        """Returns the ``attribute`` of the element found by ``selector``.
 
         Optionally asserts that the attribute value matches the specified
         assertion.
+
+        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+
+        ``attribute`` <str> Requested attribute name. **Required**
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetDomProperty(
@@ -132,6 +166,10 @@ class Getters(LibraryComponent):
         """Returns value of the textfield found by ``selector``.
 
         Optionally asserts that the value matches the specified assertion.
+
+        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         return self.get_attribute(
             selector, "value", assertion_operator, assertion_expected
@@ -149,10 +187,12 @@ class Getters(LibraryComponent):
 
         Optionally asserts that these match the specified assertion.
 
-        ``option_attribute``: which attribute shall be returned/verified.
-        Allowed values are ``<"value"|"label"|"text"|"index">``
+        ``selector`` <str> Selector from which the info is to be retrieved. **Required**
 
-        ``assertion_operator`` see `Assertions`.
+        ``option_attribute`` <SelectAttribute.label> Which attribute shall be returned/verified.
+        Allowed values are ``<"value"|"label"|"text"|"index">``. Defaults to label.
+
+        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
 
         - ``==`` and ``!=`` can work with multiple values
         - ``contains``/``*=`` only accepts one single expected value
@@ -161,13 +201,13 @@ class Getters(LibraryComponent):
 
         Example:
 
-        | `Select Options By`    | label                 | //select[2] | Email | Mobile | | |
-        | ${selected_list}     | `Get Selected Options`  | //select[2] | | | | # getter |
-        | `Get Selected Options` | //select[2] | label | == | Mobile | Mail | #assertion content |
-        | `Select Options By`    | label                 | select#names | 2 | 4 | |
-        | `Get Selected Options` | select#names | index | == | 2      | 4     | #assertion index  |
-        | `Get Selected Options` | select#names | label | *= | Mikko  |     | #assertion contains |
-        | `Get Selected Options` | select#names | label | validate | len(value) == 3  | | #assertion length |
+        | `Select Options By`    | label                  | //select[2]  | Email    | Mobile           |      |                     |
+        | ${selected_list}       | `Get Selected Options` | //select[2]  |          |                  |      | # getter            |
+        | `Get Selected Options` | //select[2]            | label        | `==`     | Mobile           | Mail | #assertion content  |
+        | `Select Options By`    | label                  | select#names | 2        | 4                |      |                     |
+        | `Get Selected Options` | select#names           | index        | `==`     | 2                | 4    | #assertion index    |
+        | `Get Selected Options` | select#names           | label        | *=       | Mikko            |      | #assertion contains |
+        | `Get Selected Options` | select#names           | label        | validate | len(value) == 3  |      | #assertion length   |
 
         """
         with self.playwright.grpc_channel() as stub:
@@ -200,32 +240,35 @@ class Getters(LibraryComponent):
     ):
         """Returns the state of the checkbox found by ``selector``.
 
-        - ``checked`` => ``True``
-        - ``unchecked`` => ``False``
+        ``selector`` <str> Selector which shall be examined
 
         Optionally asserts that the state matches the specified assertion.
 
-        ``assertion_operator`` see `Assertions`.
+        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
 
         - ``==`` and ``!=`` are allowed on boolean values
         - other operators are not accepted.
 
-        ``expected_state``: boolean value of expected state.
+        ``expected_state`` <str> boolean value of expected state.
         Strings are interpreted as booleans.
         All strings are ``${True}`` except of the
         following `FALSE, NO, OFF, 0, UNCHECKED, NONE, ${EMPTY}``.
-        (case-insensitive).
+        (case-insensitive). Defaults to unchecked
+
+        - ``checked`` => ``True``
+        - ``unchecked`` => ``False``
+
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetBoolProperty(
                 Request().ElementProperty(selector=selector, property="checked")
             )
-            logger.info(f"Checkbox is {'checked' if response.log else 'unchecked'}")
-            value: bool = response.body
-
-            return bool_verify_assertion(
-                value, assertion_operator, expected_state, f"Checkbox {selector} is"
-            )
+        logger.info(response.log)
+        value: bool = response.body
+        logger.info(f"Checkbox is {'checked' if value else 'unchecked'}")
+        return bool_verify_assertion(
+            value, assertion_operator, expected_state, f"Checkbox {selector} is"
+        )
 
     @keyword(tags=["Getter", "Assertion", "PageContent"])
     def get_element_count(
@@ -237,6 +280,14 @@ class Getters(LibraryComponent):
         """Returns the count of elements found with ``selector``.
 
         Optionally asserts that the count matches the specified assertion.
+
+        ``selector`` <str> Selector which shall be counted.
+
+        ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
+
+        ``expected_value`` <str|int> Expected value for the counting
+
+
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElementCount(
@@ -252,40 +303,42 @@ class Getters(LibraryComponent):
 
     @keyword(tags=["Getter", "Assertion", "BrowserControl"])
     def get_browser_catalog(self):
-        """ Returns all Browsers, open Contexts in them and open Pages in these contexts.
+        """ Returns all browsers, open contexts in them and open pages in these contexts.
 
             The data is parsed into a python list containing data representing the open Objects.
 
-            On the root level the data contains a list of open Browsers.
+            On the root level the data contains a list of open browsers.
 
-            `` Browser: { type: Literal['chromium', 'firefox', 'webkit'], 'id': int, contexts: List[Context]}``
-            `` Context: {type: 'context', 'id': int, pages: List[Page]} ``
-            `` Page: {type: 'page', 'id': int, title: str, url: str} ``
+            Browser: ``{type: Literal['chromium', 'firefox', 'webkit'], 'id': int, contexts: List[Context]}``
 
-            Sample: ``
-            [{
-                "type": "firefox",
-                "id": 0,
-                "contexts": [{
-                    "type": "context",
-                    "id": 0,
-                    "pages": [{
-                        "type": "page",
-                        "title": "prefilled_email_form.html",
-                        "url": "http://localhost:7272/prefilled_email_form.html",
-                        "id": "0"
-                    }]
-                }, {
-                    "type": "context",
-                    "id": 1,
-                    "pages": [{
-                        "type": "page",
-                        "title": "Login Page",
-                        "url": "http://localhost:7272/dist/",
-                        "id": "0"
-                    }]
-                }]
-            }]
+            Context: ``{type: 'context', 'id': int, pages: List[Page]}``
+
+            Page: ``{type: 'page', 'id': int, title: str, url: str}``
+
+            Sample:
+            | [{
+            |     "type": "firefox",
+            |     "id": 0,
+            |     "contexts": [{
+            |         "type": "context",
+            |         "id": 0,
+            |         "pages": [{
+            |             "type": "page",
+            |             "title": "prefilled_email_form.html",
+            |             "url": "http://localhost:7272/prefilled_email_form.html",
+            |             "id": "0"
+            |         }]
+            |     }, {
+            |         "type": "context",
+            |         "id": 1,
+            |         "pages": [{
+            |             "type": "page",
+            |             "title": "Login Page",
+            |             "url": "http://localhost:7272/dist/",
+            |             "id": "0"
+            |         }]
+            |     }]
+            | }]
 
         """
         with self.playwright.grpc_channel() as stub:
@@ -300,7 +353,14 @@ class Getters(LibraryComponent):
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Optional[Dict[str, int]] = None,
     ):
-        """Gets the current viewport dimensions """
+        """Returns the current viewport dimensions.
+
+        Optionally asserts that the count matches the specified assertion.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+
+        ``assertion_expected`` <Dict<str, int>> Defaults to None.
+         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetViewportSize(Request().Empty())
             parsed = json.loads(response.body)
@@ -314,7 +374,8 @@ class Getters(LibraryComponent):
 
         The reference can be used in subsequent selectors.
 
-        See `library introduction` for more details on the selector syntax.
+        ``selector`` <str> Selector from which shall be retrieved.
+        See `library introduction` for more details on the selector syntax. **Required**
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElement(Request().ElementSelector(selector=selector))
@@ -322,7 +383,10 @@ class Getters(LibraryComponent):
 
     @keyword(tags=["Getter", "BrowserControl"])
     def get_elements(self, selector: str):
-        """Returns a reference to playwright element handle for all matched elements by ``selector``."""
+        """Returns a reference to playwright element handle for all matched elements by ``selector``.
+
+        ``selector`` <str> Selector from which shall be retrieved. **Required**
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElements(Request().ElementSelector(selector=selector))
             data = json.loads(response.body)
@@ -336,11 +400,15 @@ class Getters(LibraryComponent):
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
     ):
-        """Gets the computed style properties of the element selected by ``selector``
+        """Gets the computed style properties of the element selected by ``selector``.
 
-            With any other value than "ALL" will try to get CSS property with key ``key``
+        Optionally matches with any sequence assertion operator.
 
-            Optionally matches with any sequence assertion operator.
+        ``selector`` <str> Selector from which the style shall be retrieved. **Required**
+
+        ``key`` <str> Key of the requested CSS property. Retrieves "ALL" styles by default.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetStyle(Request().ElementSelector(selector=selector))
@@ -365,7 +433,9 @@ class Getters(LibraryComponent):
     def get_boundingbox(self, selector: str, *keys: BoundingBoxFields):
         """ Gets elements size and location as an object {x: int, y: int, width: int, height: int}.
 
-            Optionally filters the returned values based on ``keys``.
+            ``selector`` <str> Selector from which shall be retrieved. **Required**
+
+            ``keys`` <BoundingBoxFields> Optionally filters the returned values.
 
             Example use:
             | unfiltered:       |                  |            |   |   |
@@ -380,5 +450,5 @@ class Getters(LibraryComponent):
             parsed = json.loads(response.body)
             logger.debug(parsed)
             if keys:
-                parsed = {key.value: parsed[key.value] for key in keys}
+                parsed = {key.name: parsed[key.name] for key in keys}
             return parsed
