@@ -1,17 +1,17 @@
 import contextlib
 import functools
 import os
-import socket
 import time
-from subprocess import STDOUT, Popen
+from pathlib import Path
+from subprocess import DEVNULL, STDOUT, CalledProcessError, Popen, run
 
 import grpc  # type: ignore
 from robot.libraries.BuiltIn import EXECUTION_CONTEXTS, BuiltIn  # type: ignore
 
 import Browser.generated.playwright_pb2_grpc as playwright_pb2_grpc
 from Browser.generated.playwright_pb2 import Request
-from Browser.utils import logger
-from Browser.utils.time_conversion import timestr_to_millisecs
+
+from .utils import find_free_port, logger, timestr_to_millisecs
 
 
 class Playwright:
@@ -20,6 +20,7 @@ class Playwright:
     def __init__(self, timeout: str, enable_playwright_debug: bool):
         self.timeout = timeout
         self.enable_playwright_debug = enable_playwright_debug
+        self.ensure_node_dependencies()
 
     @property
     def outputdir(self):
@@ -34,11 +35,35 @@ class Playwright:
         self.wait_until_server_up()
         return process
 
+    def ensure_node_dependencies(self):
+        # Checks if node is in PATH, errors if it isn't
+        try:
+            run(["node", "-v"], stdout=DEVNULL, check=True)
+        except (CalledProcessError, FileNotFoundError, PermissionError) as err:
+            raise RuntimeError(
+                "Couldn't execute node. Please ensure you have node.js installed and in PATH. "
+                "See https://nodejs.org/ for instructions. "
+                f"Original error is {err}"
+            )
+
+        rfbrowser_dir = Path(__file__).parent
+        installation_dir = rfbrowser_dir / "wrapper"
+        # This second application of .parent is necessary to find out that a developer setup has node_modules correctly
+        project_folder = rfbrowser_dir.parent
+        subfolders = os.listdir(project_folder) + os.listdir(installation_dir)
+
+        if "node_modules" in subfolders:
+            return
+        raise RuntimeError(
+            f"Could not find node dependencies in installation directory `{installation_dir}.` "
+            "Run `rfbrowser init` to install the dependencies."
+        )
+
     def start_playwright(self):
         workdir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "wrapper")
         playwright_script = os.path.join(workdir, "index.js")
         logfile = open(os.path.join(self.outputdir, "playwright-log.txt"), "w")
-        port = str(self.find_free_port())
+        port = str(find_free_port())
         env = dict(os.environ)
         env["PORT"] = port
         env["TIMEOUT"] = str(timestr_to_millisecs(self.timeout))
@@ -116,9 +141,3 @@ class Playwright:
         logger.debug("Closing Playwright process")
         self._playwright_process.kill()
         logger.debug("Playwright process killed")
-
-    def find_free_port(self) -> str:
-        with contextlib.closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
-            s.bind(("", 0))
-            s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-            return s.getsockname()[1]
